# Layered-retouching

[webpage](http://geometry.cs.ucl.ac.uk/projects/2017/layered-retouching/)

Tensorflow code for testing the results of Decomposing Single Images for Layered Photo Retouching by Innamorati et al.

Results can be used in any image manipulation software allowing layers (e.g. Adobe Photoshop) to edit pictures via our intrinsic and (not yet included) directional decompositions.

## Intrinsic Decomposition

### Prerequisites
- Tensorflow
- Linux or OSX
- NVIDIA GPU + CUDA CuDNN

### Getting Started

An output example of the provided code is already included in the folder `output_example`. Use the file `output_example/viewer.html` to visualize the results. Displayed results, contained in `output_example/gamma` are not in physically linear units and are only generated for visualization purposes. The folder `output_example/linear` contains results in physically linear units which can be used  for editing.

To reproduce the results in the `output_example` folder, run the following.
```sh
cd code
python compute_layers.py
```

The HTML file `output_example/viewer.html` will also be automatically generated.

### Testing

It is possible to test the code on different images by specifying a different `--input_path`. Other arguments are also available for customization.

```sh
python compute_layers.py \
--input_path # Path to the image to decompose. \
--output_path # Directory where you wish the output to reside. \
--model_path # Directory with containing a pre-trained model for testing. \
--input_gamma # Gamma of the input image. \
--size # Desired width and height of the output. Must be a power of 2. \
```

## Directional Decomposition

Our directional decomposition only uses the CNN to generate normals. The decomposition itself is generated using Spherical Harmonics. The code for the generation of the decomposition from the normals is written in a private framework and hasn't been ported yet. This file will be updated in the future to include it.

## Citation
If you use this code for your research, please cite our paper <a href="http://geometry.cs.ucl.ac.uk/projects/2017/layered-retouching/paper_docs/paper_crc.pdf">Decomposing Single Images for Layered Photo Retouching</a>:

```
@article{pix2pix2016,
 title={Decomposing Single Images for Layered Photo Retouching},
 author={Carlo Innamorati and Tobias Ritschel and Tim Weyrich and Niloy J. Mitra},
 year={2017},
 journal={Computer Graphics Forum (Proc. Eurographics Symposium on Rendering 2017)},
}
```
